# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
♻️ Add CLI | [2](https://github.com/laminlabs/lamin/pull/2) | [falexwolf](https://github.com/falexwolf) | 2023-02-24 | 0.2.0
➕ Add lndb as dependency | [1](https://github.com/laminlabs/lamin/pull/1) | [falexwolf](https://github.com/falexwolf) | 2023-02-24 |
